pub struct Edge<E> {
pub weight: E,
/* private fields */
}Expand description
The graph’s edge type. Unlike graphs, nodes and edges in hypergraphs are symmetric, in that multiple nodes can belong to the same edge and multiple edges can be incident on the same node.
Fields
weight: EImplementations