Module prelude

Re-exports

pub use crate::graph::directed::DiGraph;
pub use crate::graph::directed::Edge as DirectedEdge;
pub use crate::graph::directed::Hypergraph as DirectedHypergraph;
pub use crate::graph::directed::Node as DirectedNode;
pub use crate::graph::undirected::Edge as UndirectedEdge;
pub use crate::graph::undirected::Graph;
pub use crate::graph::undirected::Hypergraph as UndirectedHypergraph;
pub use crate::graph::undirected::Node as UndirectedNode;
pub use crate::HypergraphErrors;
pub use crate::traits::*;

Macros

hypergraph
the [hypergraph] macro works to aide the in the creation of hypergraphs by allowing users to define nodes and edges in a hypergraph in a more declarative way.
impl_graph_basics
impl_weights