pub trait HypergraphBasics<'a>: GraphBasics<'a> {
type DualType;
// Required methods
fn uniform(&'a self) -> bool;
fn dual(&'a self) -> Self::DualType;
}Required Associated Types
Required Methods
Sourcefn uniform(&'a self) -> bool
fn uniform(&'a self) -> bool
Returns none if the hypergraph is not uniform, or the size of the hyperedges if it is. A hypergraph is uniform if all hyperedges have the same number of nodes. For example, a hypergraph with hyperedges of size 3 is 3-uniform.
fn dual(&'a self) -> Self::DualType
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".